@@ -2,7 +2,7 @@
 #
 # barriosqdata.py - barrioSquare data access layer
 # 
-# barrioSquare v0.3.7
+# barrioSquare v0.3.8
 # Copyright(c) 2010 Chili Technologies LLC
 # http://www.chilitechno.com/fster
 #
@@ -32,7 +32,7 @@
 # ============================================================================
 # Name        : barriodata.py
 # Author      : Chris J. Burris - chris@chilitechno.com
-# Version     : 0.3.7
+# Version     : 0.3.8
 # Description : barrioSquare
 # ============================================================================
 
@@ -204,6 +204,7 @@ class DataWorkerThread(QtCore.QThread):
 
 class DataManager(QtCore.QObject):
 	def __init__(self,sourceDbFile,dbFilePath):
+                QtCore.QObject.__init__(self)
 		dbExists = os.path.exists(dbFilePath)
 		if not dbExists:		
 			# copy db file from app directory
@@ -374,7 +375,7 @@ class DataManager(QtCore.QObject):
 		queryParams = { }
 
 		queryParams['Action'] = 'Delete'
-		queryParams['DELETE'] = "DELETE FROM VenueMayors WHERE VenueID in (%s)" % venueIDList
+		queryParams['DELETE'] = "DELETE FROM VenueMayors WHERE userID = %s" % userID
 		
 		# queryParams['UPDATE'] = "UPDATE UserCheckinHistory SET userID='%s', calculatedDistance=%s, distanceCalcDate='%s', CustomVenue='%s', displayString='%s' WHERE id='%s'" % (self.safeStr(userID),calcDistance,strNow,self.safeStr(customVenueName),self.safeStr(displayString),self.safeStr(checkinID))
 		if self.insertUpdateDeleteThread != None:
