@@ -1,6 +1,6 @@
 # This file is part of barrioSquare.
 # 
-# v0.2.3
+# v0.2.5
 #
 # barrioSquare is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@ lockCount = 0
 partialLockCount = 0
 locationMethodType = int(sys.argv[1])
 serverPort = int(sys.argv[2])
+quitAfterLocation = int(sys.argv[3])
 
 # create the socket to back to the server
 sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
@@ -80,7 +81,7 @@ def on_changed(device, data):
 			currentLatitude = device.fix[4]
 			currentLongitude = device.fix[5]
 			horizAcc = str(device.fix[6])
-			vertAcc = str(device.fix[7])
+			vertAcc = str(device.fix[8])
 			# print device.fix[6]
 			# print "lat = %f" % currentLatitude
 			# print "long = %f" % currentLongitude
@@ -107,6 +108,9 @@ def on_changed(device, data):
 				sock.send(sockCommand + '\n\r')
 			except:
 				data.stop()
+				
+			if quitAfterLocation == 1:
+				data.stop()
 			
 			#
 			# locationFile = open(userPreferencesDir + 'CurrentLocation.txt','w')
